<img src="http://i.imgur.com/TMKcgIV.png" width="35" height="35"> BokehJS
=========================================================================

BokehJS is a front-end JavaScript library for [Bokeh](http://github.com/bokeh/bokeh).

The architecture of the library facilitates easy manipulation of the components
and configuration of a plot from server-side code in python or other languages.
However, BokehJS can also be used directly as a standalone JavaScript library,
with plot data embedded directly into the page, retrieved via AJAX calls, or
supplied by a separate Bokeh Plot server.

Building
--------

Please refer to the [BokehJS section](https://docs.bokeh.org/en/latest/docs/dev_guide/bokehjs.html)
of the [Bokeh Developer Guide](https://docs.bokeh.org/en/latest/docs/dev_guide.html)
for information about building, testing and demoing BokehJS.

Contributing
------------

We always appreciate feedback and value contributions.  The core developers are
working hard towards applying Bokeh and BokehJS towards some specific projects,
so the development priorities will tend to center around those tasks, until the
project reaches a point of stability.

Please join the discussion on the [Bokeh project Discourse](https://discourse.bokeh.org).
